﻿<#
The sample scripts are not supported under any Microsoft standard support 
program or service. The sample scripts are provided AS IS without warranty  
of any kind. Microsoft further disclaims all implied warranties including,  
without limitation, any implied warranties of merchantability or of fitness for 
a particular purpose. The entire risk arising out of the use or performance of  
the sample scripts and documentation remains with you. In no event shall 
Microsoft, its authors, or anyone else involved in the creation, production, or 
delivery of the scripts be liable for any damages whatsoever (including, 
without limitation, damages for loss of business profits, business interruption, 
loss of business information, or other pecuniary loss) arising out of the use 
of or inability to use the sample scripts or documentation, even if Microsoft 
has been advised of the possibility of such damages.
#> 

#requires -Version 3
Import-LocalizedData -BindingVariable Messages

Function New-OSCPSCustomErrorRecord
{
	#This function is used to create a PowerShell ErrorRecord
	[CmdletBinding()]
	Param
	(		
		[Parameter(Mandatory=$true,Position=1)][String]$ExceptionString,
		[Parameter(Mandatory=$true,Position=2)][String]$ErrorID,
		[Parameter(Mandatory=$true,Position=3)][System.Management.Automation.ErrorCategory]$ErrorCategory,
		[Parameter(Mandatory=$true,Position=4)][PSObject]$TargetObject
	)
	Process
	{
		$exception = New-Object System.Management.Automation.RuntimeException($ExceptionString)
		$customError = New-Object System.Management.Automation.ErrorRecord($exception,$ErrorID,$ErrorCategory,$TargetObject)
		return $customError
	}
}
	
function Remove-OSCAppxPackage
{
	<#
		.SYNOPSIS
			The Remove-OSCAppxPackage command will remove Windows Store Appx packages.

		.DESCRIPTION
			This command can help you to remove several Windows Store Apps at one time.  
			
		.EXAMPLE
			PS C:\> Remove-OSCAppxPackage
			
			Description
			-----------
			List all Windows Store apps, and remove the apps specified by user.
		
		.LINK
			Windows PowerShell Advanced Function
			http://technet.microsoft.com/en-us/library/dd315326.aspx
		
		.LINK
			Get-AppxPackage
			http://technet.microsoft.com/en-us/library/hh856044.aspx
			
		.LINK
			Remove-AppxPackage
			http://technet.microsoft.com/en-us/library/hh856038.aspx	
	#>
	[CmdletBinding(SupportsShouldProcess=$true,ConfirmImpact="High")]
	param
	()
	process
	{
		$index=1
		$apps=Get-AppxPackage
		#return entire listing of applications 
		Write-Host "ID`t App name"
		foreach ($app in $apps)
		{
			Write-Host " $index`t $($app.name)"
			$index++
		}
		$IDs=Read-Host -Prompt "Which Apps do you want to remove? `nInput their IDs and seperate IDs by comma"
		#check whether input values are correct
		try
		{	
			[int[]]$IDs=$IDs -split ","
		}
		catch
		{
			$errorMsg = $Messages.IncorrectInput
			$errorMsg = $errorMsg -replace "Placeholder01",$IDs
			$customError = New-OSCPSCustomErrorRecord `
			-ExceptionString $errorMsg `
			-ErrorCategory NotSpecified -ErrorID 1 -TargetObject $pscmdlet
			$pscmdlet.WriteError($customError)
			return
		}
		foreach ($ID in $IDs)
		{
			#check id is in the range
			if ($ID -ge 1 -and $ID -le $apps.count)
			{
				$ID--
				#Remove each app
				$AppName=$apps[$ID].name
				if($PSCmdlet.ShouldProcess("$AppName"))
				{
					Remove-AppxPackage -Package $apps[$ID] 
					if (-not(Get-AppxPackage -Name $AppName))
					{
						Write-Host "$AppName has been removed successfully"
					}
					else
					{
						Write-Host "Remove $AppName failed!"
					}
				}
			}
			else
			{
				$errorMsg = $Messages.WrongID
				$errorMsg = $errorMsg -replace "Placeholder01",$ID
				$customError = New-OSCPSCustomErrorRecord `
				-ExceptionString $errorMsg `
				-ErrorCategory NotSpecified -ErrorID 1 -TargetObject $pscmdlet
				$pscmdlet.WriteError($customError)
			}
		}
	}
}